using System;
using System.Collections.Generic;
using System.IO;
using System.Runtime.ExceptionServices;
using UnityEngine;
using UnityEngine.Events;


namespace RRM
{
    public class RRM
    {
        public static void Main()
        {
            ModAPI.Register(
                    new Modification()
                    {
                        OriginalItem = ModAPI.FindSpawnable("Revolver"),
                        NameOverride = "Revolver -RRM",
                        DescriptionOverride = "Revolver for playing Russian roulette.",
                        CategoryOverride = ModAPI.FindCategory("Firearms"),
                        ThumbnailOverride = ModAPI.LoadSprite("RevolverView.png"),
                        AfterSpawn = (Instance) =>
                        {
                            Instance.AddComponent<RevolverBehaviour>();
                            Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("RevolverSprite.png", 1f);
                            Instance.FixColliders();
                        }
                    });
        }
    }
    public class RevolverBehaviour : MonoBehaviour
    {
        public int bullets = 1;
        public int value = UnityEngine.Random.Range(1, 7);
        public FirearmBehaviour firearm;

        void Start()
        {
            firearm = this.GetComponent<FirearmBehaviour>();
            Cartridge customCartridge = ModAPI.FindCartridge("9mm");
            customCartridge.name = "RevolverBullet";
            customCartridge.Damage *= 1.2f;
            customCartridge.StartSpeed *= 1f;
            customCartridge.PenetrationRandomAngleMultiplier *= 3f;
            customCartridge.Recoil *= 4f;
            customCartridge.ImpactForce *= 1f;
            firearm.Cartridge = customCartridge;
            if (value > bullets)
            {
                firearm.BulletsPerShot = 0;
                firearm.ShotSounds = new AudioClip[]
{
                ModAPI.LoadSound("sound.mp3")
};
            }
            else
            {
                firearm.BulletsPerShot = 1;
                firearm.ShotSounds = new AudioClip[]
{
                ModAPI.LoadSound("shot.mp3")
};
            }
        }

        void ContextMenu()
        {
            AudioClip sound;
            AudioSource audioSource;
            audioSource = this.GetComponent<AudioSource>();
            sound = ModAPI.LoadSound("spin.wav");
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("spinbutt", "Spin", "Spin the drum of the revolver", () =>
            {
                value = UnityEngine.Random.Range(1, 7);
                audioSource.minDistance = 20;
                audioSource.maxDistance = 40;
                audioSource.clip = sound;
                audioSource.Play();
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt0", "0/6 bullets", "Set the value of bullets in drum 0", () =>
            {
                bullets = 0;
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt1", "1/6 bullets", "Set the value of bullets in drum 1", () =>
            {
                bullets = 1;
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt2", "2/6 bullets", "Set the value of bullets in drum 2", () =>
            {
                bullets = 2;
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt3", "3/6 bullets", "Set the value of bullets in drum 3", () =>
            {
                bullets = 3;
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt4", "4/6 bullets", "Set the value of bullets in drum 4", () =>
            {
                bullets = 4;
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt5", "5/6 bullets", "Set the value of bullets in drum 5", () =>
            {
                bullets = 5;
            }));
            this.GetComponent<PhysicalBehaviour>().ContextMenuOptions.Buttons.Add(new ContextMenuButton("butt6", "6/6 bullets", "Set the value of bullets in drum 6", () =>
            {
                bullets = 6;
            }));
        }

        void Use()
        {
            firearm = this.GetComponent<FirearmBehaviour>();
            if (value < 6)
            {
                value = value + 1;
            }
            else
            {
                value = 1;
            }

            if (value > bullets)
            {
                firearm.BulletsPerShot = 0;
                firearm.ShotSounds = new AudioClip[]
{
                ModAPI.LoadSound("sound.mp3")
};
            }
            else
            {
                firearm.BulletsPerShot = 1;
                firearm.ShotSounds = new AudioClip[]
{
                ModAPI.LoadSound("shot.mp3")
};
            }
        }
        void Awake()
        {
            ContextMenu();
        }
}
}